#
# spec file for package libspatialite
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   8
%define libname %{name}%{sover}
Name:           libspatialite
Version:        5.1.0
Release:        22.9
Summary:        Spatial SQLite
License:        MPL-1.1
Group:          Development/Libraries/C and C++
URL:            https://www.gaia-gis.it/fossil/libspatialite/index
Source:         https://www.gaia-gis.it/gaia-sins/libspatialite-sources/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libgeos-devel
BuildRequires:  pkgconfig
# Mandatory for tests to have proj.db
BuildRequires:  proj
BuildRequires:  sqlite-devel >= 3.7.3
BuildRequires:  pkgconfig(freexl)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(proj)
BuildRequires:  pkgconfig(rttopo)
BuildRequires:  pkgconfig(zlib)

%description
The SpatiaLite extension enables SQLite to support spatial data too
[aka GEOMETRY], in a way conformant to OpenGis specifications.

%package -n %{libname}
Summary:        Spatial SQLite
Group:          System/Libraries

%description -n %{libname}
The SpatiaLite extension enables SQLite to support spatial data too
[aka GEOMETRY], in a way conformant to OpenGis specifications.

%package -n mod_spatialite
Summary:        Spatial SQLite extension
Requires:       %{libname} = %{version}

%description -n mod_spatialite
The SpatiaLite extension enables SQLite to support spatial data too
[aka GEOMETRY], in a way conformant to OpenGis specifications.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       pkgconfig(freexl)
Requires:       pkgconfig(libxml-2.0)
Requires:       pkgconfig(minizip)
Requires:       pkgconfig(proj)
Requires:       pkgconfig(rttopo)

%description devel
This package contains all necessary include files and libraries needed
to compile and develop applications that use libspatialite.

%prep
%setup -q

%build
%configure --disable-static
%make_build
# build tests
%make_build check TESTS=""

%check
# Don't fail build - four failures (reported to upstream)
%make_build check || :

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%doc README README.coverage
%{_libdir}/libspatialite.so.%{sover}*
%{_libdir}/mod_spatialite.so.%{sover}*

%files -n mod_spatialite
%license COPYING
%doc README README.coverage
%{_libdir}/mod_spatialite.so

%files devel
%license COPYING
%doc README README.coverage
%{_includedir}/*
%{_libdir}/libspatialite.so
%{_libdir}/pkgconfig/spatialite.pc

%changelog
* Wed Jan  3 2024 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.0
  * No changelog provided
* Mon Dec 25 2023 Dirk Stoecker <opensuse@dstoecker.de>
- Add missing requirements for devel package
* Fri Nov  5 2021 Ben Greiner <code@bnavigator.de>
- Add subpackage mod_spatialite
  * This library is loaded by sqlite's load_extension by its
    unversioned '*.so' name -- boo#1185415
* Tue May 11 2021 Bruno Friedmann <bruno@ioda-net.ch>
- Update to version 5.0.1
  Documentation available at
  https://www.gaia-gis.it/gaia-sins/spatialite_topics.html
  + Add Buildrequires to librttopo (mandatory) (new package)
  + Drop merged libspatialite-deprecated-proj-api.patch
- Spec cleanup
* Sun Mar 17 2019 Mykola Krachkovsky <w01dnick@gmail.com>
- fixed build with newer libproj (using of deprecated API)
  * added libspatialite-deprecated-proj-api.patch
* Mon Dec  4 2017 mpluskal@suse.com
- Do not build documentation
- Small spec file cleanup
* Sun Nov  8 2015 p.drouand@gmail.com
- Update to version 4.3.0a
  * No changelog provided
- Add graphviz build requires; new dependency
* Sat Mar  7 2015 mpluskal@suse.com
- Remove unknown configure flags
- Don't fail build because of failing test
* Wed Feb  4 2015 mpluskal@suse.com
- Fix library category
- Actually try to use fdupes
* Wed Feb  4 2015 kukuk@suse.de
- Fix library package name according shared library policy
* Sat Jan 31 2015 mpluskal@suse.com
- Minor spec file cleanup
- Use url for source
- Install LICENCE, README and README.coverage
- Build documentation and bundle it with -devel package
- Enable and execute tests
- Update to version 4.2.0 (no changelog provided)
* Sun Jul  7 2013 tzotsos@opensuse.org
- Updated to version 4.1.1
* Sun Feb 10 2013 behrisch@users.sourceforge.net
- Added CFLAGS="-std=c99" for older compilers
* Mon Nov 26 2012 tzotsos@opensuse.org
- Updated to version 4.0.0
* Thu Mar 22 2012 behrisch@users.sf.net
- disable geocallbacks for RHEL / CentOS build (due to outdated sqlite)
* Tue Mar  6 2012 tzotsos@opensuse.org
- Updated to version 3.0.1
* Wed Aug 17 2011 idonmez@novell.com
- Add libspatialite-no-proj-la.patch: don't look for libproj.la file
- Disable static libraries
* Fri Apr 29 2011 sasch.pe@gmx.de
- Spec file cleanup:
  - Proper license header and preamble
  - Use RPM macros where applicable
  - Use smp-flags for make
  - Fixed Fedora-style changes file
  - Proper post/postun for libspatialite1
  - Use group Development/Libraries/C and C++
* Wed Apr 13 2011 behrisch@users.sourceforge.net
- CentOS build
* Mon Apr 11 2011 behrisch@users.sourceforge.net
- Fixing 64bit build
* Mon Dec 20 2010 tzotsos@gmail.com
- Initial build
